Skip to contents

Creates a plot that shows all available Core Surveillance color palettes with their color codes and names.

Usage

display_all_palettes()

Value

A ggplot2 plot that shows all the color palettes.

See also

Other csstyle_utilities: colors, every_nth(), set_global()

Examples

# Display all available color palettes
display_all_palettes()