Format numbers as percentages with Norwegian conventions (0 decimal places)
Source:R/format_num.R
format_num_as_nor_perc.RdFormats numeric values as percentages with Norwegian conventions and 0 decimal places.
Formats numeric values as percentages with Norwegian conventions and 1 decimal place.
Formats numeric values as percentages with Norwegian conventions and 2 decimal places.
Value
Character vector of Norwegian-formatted numbers with a "
Character vector of Norwegian-formatted numbers with a "
Character vector of Norwegian-formatted numbers with a "