A list of the named colors, the base color, and the predefined color palettes. The Core Surveillance styling functions take their colors from this list.
Format
A list with the following elements:
- named_colors
Named character vector of 12 colors, "H1" to "H12". "H1" to "H7" are hex codes. "H8" to "H12" are R color names.
- base
The base color, element "H1" of
named_colors.- palettes
Named list of palettes:
primary_1toprimary_12(1 to 12 levels),warning_3(3 levels) andposneg_2(2 levels). Theposnegfamily has no 1-level palette, soscale_color_cs(palette = "posneg")accepts 2 levels only.- palette_names
Character vector of the palette family names ("primary", "posneg", "warning").
See also
Other csstyle_utilities:
display_all_palettes(),
every_nth(),
set_global()
Examples
# Access named colors
colors$named_colors["H1"]
#> H1
#> "#393C61"
# View primary palette
colors$palettes$primary_3
#> H1 H4 H2
#> "#393C61" "#709900" "#0975B5"
# See all available palettes
names(colors$palettes)
#> [1] "primary_1" "primary_2" "primary_3" "primary_4" "primary_5"
#> [6] "primary_6" "primary_7" "primary_8" "primary_9" "primary_10"
#> [11] "primary_11" "primary_12" "warning_3" "posneg_2"