Creates a plot that shows all available Core Surveillance color palettes with their color codes and names.
See also
Other csstyle_utilities:
colors,
every_nth(),
set_global()
Creates a plot that shows all available Core Surveillance color palettes with their color codes and names.
Other csstyle_utilities:
colors,
every_nth(),
set_global()