Format cstidy age codes as factor with Norwegian text
Source:R/format_cstidy_age_as.r
format_cstidy_age_as.RdConverts age codes such as "009" or "005_014" to readable Norwegian age labels.
Converts age codes to readable Norwegian age labels and returns them as a character vector.
Value
Factor vector of Norwegian age labels, for example "9 år" or "5-14 år".
Character vector of Norwegian age labels, for example "9 år" or "5-14 år".
See also
format_location_code_as_factor applies the same factor
and character pair to Norwegian location codes.
vignette("csstyle") does not demonstrate these two age functions.