Format numbers as percentages with journal conventions (0 decimal places)
Source:R/format_num.R
format_num_as_journal_perc.RdFormats numeric values as percentages with journal conventions and 0 decimal places.
Formats numeric values as percentages with journal conventions and 1 decimal place.
Formats numeric values as percentages with journal conventions and 2 decimal places.
Usage
format_num_as_journal_perc_0(x)
format_num_as_journal_perc_1(x)
format_num_as_journal_perc_2(x)Value
Character vector of journal-formatted numbers with a "
Character vector of journal-formatted numbers with a "
Character vector of journal-formatted numbers with a "
See also
Other csstyle_journal_formatters:
format_num_as_journal_invlog10_1(),
format_num_as_journal_invlog2_1(),
format_num_as_journal_invloge_1(),
format_num_as_journal_num_0(),
format_num_as_journal_per100k_0()